@@ -18,7 +18,7 @@ use XML::Feed;
 use vars qw{$VERSION};
 
 BEGIN {
-  $VERSION = '0.56';
+  $VERSION = '1.1.3';
 }
 
 with 'MooseX::Traits';
@@ -78,6 +78,12 @@ has $_ => (
   is  => 'ro',
 ) for qw( self_link title description url agent );
 
+has entry_sort_order => (
+  isa => 'Str',
+  is  => 'ro',
+  default => 'modified',
+);
+
 =head1 NAME
 
 Perlanet - A program for creating programs that aggregate web feeds (both
@@ -168,10 +174,10 @@ NB: This method also modifies the contents of L</feeds>.
 =cut
 
 sub fetch_feeds {
-  my ($self, @feeds) = @_;
+  my ($self, $feeds) = @_;
 
   my @valid_feeds;
-  for my $feed (@feeds) {
+  for my $feed (@$feeds) {
     my $response = $self->fetch_page($feed->url);
 
     if ($response->is_error) {
@@ -200,7 +206,7 @@ sub fetch_feeds {
     };
   }
 
-  return @valid_feeds;
+  return \@valid_feeds;
 }
 
 =head2 select_entries
@@ -213,12 +219,14 @@ Returns a combined list of L<Perlanet::Entry> objects from all given feeds.
 =cut
 
 sub select_entries {
-  my ($self, @feeds) = @_;
+  my ($self, $feeds) = @_;
 
   my @feed_entries;
-  for my $feed (@feeds) {
+  for my $feed (@$feeds) {
     my @entries = $feed->_xml_feed->entries;
 
+    @entries = @{ $self->sort_entries(\@entries) };
+
     if ($self->entries_per_feed and @entries > $self->entries_per_feed) {
       $#entries = $self->entries_per_feed - 1;
     }
@@ -239,7 +247,7 @@ sub select_entries {
       } @entries;
   }
 
-  return @feed_entries;
+  return \@feed_entries;
 }
 
 =head2 sort_entries
@@ -255,23 +263,37 @@ Takes a list of L<Perlanet::Entry>s, and returns an ordered list.
 =cut
 
 sub sort_entries {
-  my ($self, @entries) = @_;
+  my ($self, $entries) = @_;
   my $day_zero = DateTime->from_epoch(epoch => 0);
 
-  @entries = grep {
-      ($_->issued || $_->modified || $day_zero) < $self->cutoff
-  } sort {
+  my @entries;
+
+  if ($self->entry_sort_order eq 'modified') {
+    @entries = grep {
+      ($_->modified || $_->issued || $day_zero) < $self->cutoff
+    } sort {
       ($b->modified || $b->issued || $day_zero)
           <=>
       ($a->modified || $a->issued || $day_zero)
-  } @entries;
+    } @$entries;
+  } elsif ($self->entry_sort_order eq 'issued') {
+    @entries = grep {
+      ($_->issued || $_->modified || $day_zero) < $self->cutoff
+    } sort {
+      ($b->issued || $b->modified || $day_zero)
+          <=>
+      ($a->issued || $a->modified || $day_zero)
+    } @$entries;
+  } else {
+    die 'Invalid entry sort order: ' . $self->entry_sort_order;
+  }
 
   # Only need so many entries
   if ($self->entries && @entries > $self->entries) {
     $#entries = $self->entries - 1;
   }
 
-  return @entries;
+  return \@entries;
 }
 
 =head2 build_feed
@@ -285,7 +307,7 @@ that is the actual feed for the planet.
 =cut
 
 sub build_feed {
-  my ($self, @entries) = @_;
+  my ($self, $entries) = @_;
 
   my $self_url = $self->self_link;
 
@@ -293,12 +315,14 @@ sub build_feed {
   $f->title($self->title)             if defined $self->title;
   $f->url($self->url)                 if defined $self->url;
   $f->description($self->description) if defined $self->description;
-  $f->author($self->author->{name})   if defined $self->author->{name};
-  $f->email($self->author->{email})   if defined $self->author->{email};
+  if (defined $self->{'author'} ) {
+    $f->author($self->author->{name})   if defined $self->author->{name};
+    $f->email($self->author->{email})   if defined $self->author->{email};
+  }
   $f->self_link($self->url)           if defined $self->url;
   $f->id($self->url)                  if defined $self->url;
 
-  $f->add_entry($_) for @entries;
+  $f->add_entry($_) for @$entries;
 
   return $f;
 }
@@ -326,11 +350,11 @@ cleaned entries.
 =cut
 
 sub clean_entries {
-  my ($self, @entries) = @_;
+  my ($self, $entries) = @_;
 
   my @clean_entries;
 
-  foreach (@entries) {
+  foreach (@$entries) {
     if (my $body = $_->content->body) {
       my $cleaned = $self->clean_html($body);
       $_->content->body($cleaned);
@@ -344,7 +368,7 @@ sub clean_entries {
     push @clean_entries, $_;
   }
 
-  return @clean_entries;
+  return \@clean_entries;
 }
 
 =head2 render
@@ -372,26 +396,24 @@ The main method which runs the perlanet process.
 sub run {
   my $self = shift;
 
-  my @feeds    = $self->fetch_feeds(@{$self->feeds});
-  my @selected = $self->select_entries(@feeds);
-  my @sorted   = $self->sort_entries(@selected);
-  my @cleaned  = $self->clean_entries(@sorted);
-  my $feed     = $self->build_feed(@cleaned);
+  my $feeds    = $self->fetch_feeds($self->feeds);
+  my $selected = $self->select_entries($feeds);
+  my $sorted   = $self->sort_entries($selected);
+  my $cleaned  = $self->clean_entries($sorted);
+  my $feed     = $self->build_feed($cleaned);
 
   $self->render($feed);
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
 =head1 TO DO
 
-See http://wiki.github.com/davorg/perlanet
+See L<http://wiki.github.com/davorg/perlanet/issues>
 
 =head1 SUPPORT
 
-There is a mailing list which acts as both a place for developers to talk
-about maintaining and improving Perlanet and also for users to get support.
-You can sign up to this list at
-L<http://lists.mag-sol.com/mailman/listinfo/perlanet>
-
 To report bugs in Perlanet, please use the CPAN request tracker. You can
 either use the web page at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Perlanet> or send an email
